@@ -1,3 +1,6 @@
+
+import logging
+logger = logging.getLogger(__file__)
 import ast
 import importlib
 import inspect
@@ -124,15 +127,24 @@ class Config:
     SCIPION_LOG = _join(SCIPION_LOGS, 'scipion.log')
     "Path to the file where scipion will write GUI logging messages. Defaults to SCIPION_LOGS/scipion.log"
 
+    SCIPION_LOG_FORMAT = _get('SCIPION_LOG_FORMAT', "%(message)s")
+    "Format for all the log lines, defaults to %(message)s. To compose the format see https://docs.python.org/3/library/logging.html#logrecord-attributes"
+
     SCIPION_LOG_LEVEL = _get(SCIPION_LOG_LEVEL, 'INFO')
     "Default logging level. String among CRITICAL, ERROR, WARNING, INFO, DEBUG, NOTSET. Default value is INFO."
 
+    NO_COLOR = _get('NO_COLOR', '')
+    "Comply with https://no-color.org/ initiative. Set it to something different than '' to deactivate colors in the output."
+
     SCIPION_SCRATCH = _get(SCIPION_SCRATCH, None)
     "Optional. Path to a location mounted in a scratch drive (SSD,...)"
 
     SCIPION_TESTS_OUTPUT = _get('SCIPION_TESTS_OUTPUT', _join(SCIPION_USER_DATA, 'Tests'))
     "Path to a folder Where the output of the tests will be written. Defaults to SCIPION_USER_DATA/Tests."
 
+    SCIPION_TEST_NOSYNC = _get('SCIPION_TEST_NOSYNC', "False")
+    "Set it to 1, True, Yes or y to cancel test dataset synchronization. Needed when updating files in a dataset."
+
     SCIPION_SUPPORT_EMAIL = _get('SCIPION_SUPPORT_EMAIL', 'scipion@cnb.csic.es')
 
     SCIPION_LOGO = _get('SCIPION_LOGO', 'scipion_logo.gif')
@@ -186,9 +198,16 @@ class Config:
     "If set to False, Scipion developers will know almost nothing about Scipion usage and will have less information to improve it."
 
     SCIPION_CWD = _get('SCIPION_CWD', os.path.abspath(os.getcwd()))
+    "Directory when scipion was launched"
 
-    # Refresh the displayed runs with a thread
     SCIPION_GUI_REFRESH_IN_THREAD = _get('SCIPION_GUI_REFRESH_IN_THREAD', 'False')
+    "True to refresh the runs graph with a thread. Unstable."
+
+    SCIPION_GUI_REFRESH_INITIAL_WAIT = int(_get("SCIPION_GUI_REFRESH_INITIAL_WAIT", 5))
+    "Seconds to wait after a manual refresh"
+
+    SCIPION_GUI_CANCEL_AUTO_REFRESH = _get("SCIPION_GUI_CANCEL_AUTO_REFRESH","False")
+    "Set it to True to cancel automatic refresh of the runs."
 
     # Cancel shutil fast copy. In GPFS, shutil.copy does fail when trying a fastcopy and does not fallback on the slow copy.
     SCIPION_CANCEL_FASTCOPY = _get('SCIPION_CANCEL_FASTCOPY', None)
@@ -261,8 +280,8 @@ class Config:
             for name, value in vars(baseCls).items():
                 # Skip methods and internal attributes starting with __
                 # (e.g __doc__, __module__, etc)
-                if isinstance(value, str) and not name.startswith('__'):
-                    configVars[name] = value
+                if (isinstance(value, str) or isinstance(value, int)) and not name.startswith('__'):
+                    configVars[name] = str(value)
         return configVars
 
     @classmethod
@@ -301,9 +320,10 @@ class Config:
         return os.path.join(get_paths()['data'], "lib")
 
     @staticmethod
-    def debugOn(*args):
+    def debugOn():
+        """ Returns a True if debug mode (SCIPION_DEBUG variable) is active """
         from .utils import envVarOn
-        return bool(envVarOn(SCIPION_DEBUG, *args))
+        return bool(envVarOn(SCIPION_DEBUG))
 
     @staticmethod
     def toggleDebug():
@@ -354,6 +374,11 @@ class Config:
     def getUpdateSetAttemptsWait(cls):
         return cls.SCIPION_UPDATE_SET_ATTEMPT_WAIT
 
+    @classmethod
+    def colorsInTerminal(cls):
+        """ Returns true if colors are allowed. Based on NO_COLOR variable. Undefined or '' colors are enabled"""
+        return cls.NO_COLOR == ''
+
 
 # Add bindings folder to sys.path
 sys.path.append(Config.getBindingsFolder())
