@@ -39,6 +39,7 @@ from .executor import (StepExecutor, ThreadStepExecutor, MPIStepExecutor,
                        QueueStepExecutor)
 from .constants import *
 from .params import Form
+from ..utils import getFileSize
 
 SCHEDULE_LOG = 'schedule.log'
 
@@ -352,6 +353,7 @@ class Protocol(Step):
 
     def __init__(self, **kwargs):
         Step.__init__(self, **kwargs)
+        self._size = None
         self._steps = []  # List of steps that will be executed
         # All generated filePaths should be inside workingDir
         self.workingDir = String(kwargs.get('workingDir', '.'))
@@ -478,7 +480,7 @@ class Protocol(Step):
         self.__tryUpdateOutputSet(outputName, outputSet, state)
 
     def __tryUpdateOutputSet(self, outputName, outputSet,
-                            state=Set.STREAM_OPEN, tries=1):
+                            state=Set.STREAM_OPEN, tries=1, firstException=None):
         try:
             # Update the set with the streamState value (either OPEN or CLOSED)
             outputSet.setStreamState(state)
@@ -498,14 +500,16 @@ class Protocol(Step):
             outputSet.close()
 
         except Exception as ex:
-            print("Error trying to update output of protocol, tries=%d" % tries)
 
             if tries > pw.Config.getUpdateSetAttempts():
-                raise ex
+                raise BlockingIOError("Can't update %s (output) of %s after %s attempts. Reason: %s. "
+                                      "Concurrency, a non writable file system or a quota exceeded could be among the causes." %
+                                      (outputName, self,tries-1, ex)) from firstException
             else:
+                logger.warning("Trying to update %s (output) of protocol %s, attempt=%d: %s " % (outputName, self, tries, ex))
                 time.sleep(pw.Config.getUpdateSetAttemptsWait())
                 self.__tryUpdateOutputSet(outputName, outputSet, state,
-                                          tries + 1)
+                                          tries + 1, firstException= ex if tries==1 else firstException)
 
     def hasExpert(self):
         """ This function checks if the protocol has
@@ -556,10 +560,11 @@ class Protocol(Step):
         """ This function will retrieve the text value
         of an enum parameter in the definition, taking the actual value in
         the protocol.
-        Params:
-            paramName: the name of the enum param.
-        Returns:
-            the string value corresponding to the enum choice.
+
+        :param paramName: the name of the enum param.
+
+        :returns: the string value corresponding to the enum choice.
+
         """
         index = getattr(self, paramName).get()
         return self.getParam(paramName).choices[index]
@@ -666,34 +671,36 @@ class Protocol(Step):
             elif attr.isPointer():
                 yield key, attr
 
-    def inputProtocolDict(self):
+    def getProtocolsToUpdate(self):
         """
-        This function returns a dictionary of protocols that need to update
+        This function returns a list of protocols ids that need to update
         their database to launch this protocol (this method is only used
         when a WORKFLOW is restarted or continued).
         Actions done here are:
-        1. Iterate over the main input Pointer of this protocol
-           (here, 3 different cases are analyzed)
 
-           A) When the pointer points to a protocol
+        #. Iterate over the main input Pointer of this protocol
+            (here, 3 different cases are analyzed):
 
-           B) When the pointer points to another object (INDIRECTLY).
-              - The pointer has an _extended value (new parameters configuration
+            A #. When the pointer points to a protocol
+
+            B #. When the pointer points to another object (INDIRECTLY).
+                The pointer has an _extended value (new parameters configuration
                 in the protocol)
 
-           C) When the pointer points to another object (DIRECTLY).
+            C #. When the pointer points to another object (DIRECTLY).
+
               - The pointer has not an _extended value (old parameters
                 configuration in the protocol)
 
-        2. The PROTOCOL to which the pointer points is determined and saved in
-           the dictionary
+        #. The PROTOCOL to which the pointer points is determined and saved in
+            the list
 
-        3. If this pointer points to another object (case B and C):
-           - Iterate over the main attributes of this pointer
-           - if any attribute is a pointer, then we move to PROTOCOL and repeat
-             this procedure from step 1
+        #. If this pointer points to a set (case B and C):
+
+          - Iterate over the main attributes of the set
+            - if attribute is a pointer then we add the pointed protocol to the ids list
         """
-        protocolDict = {}
+        protocolIds = []
         protocol = None
         for key, attrInput in self.iterInputAttributes():
             output = attrInput.get()
@@ -709,29 +716,30 @@ class Protocol(Step):
                     else:
                         # This is a problem, since protocols coming from
                         # Pointers do not have the __project set.
-                        # We do not have an clear way to get the protocol if
+                        # We do not have a clear way to get the protocol if
                         # we do not have the project object associated
                         # This case implies Direct Pointers to Sets
                         # (without extended): hopefully this will only be
                         # created from tests
-                        print("Can't get protocol info from input attribute."
+                        logger.warning("Can't get %s info from %s."
                               " This could render unexpected results when "
-                              "scheduling protocols.")
+                              "scheduling protocols. Value: %s" % (key, self, attrInput))
                         continue
 
+                # If there is output
                 if output is not None:
+                    # For each output attribute: Looking for pointers like SetOfCoordinates.micrographs
                     for k, attr in output.getAttributes():
+                        # If it's a pointer
                         if isinstance(attr, Pointer):
-                            if attr.get() is not None:
-                                auxDict = protocol.inputProtocolDict()
-                                for auxKey in auxDict:
-                                    if auxKey not in protocolDict.keys():
-                                        protocolDict[auxKey] = auxDict[auxKey]
-                                break
+                            logger.debug("Pointer found in output: %s.%s (%s)" % (output, k, attr))
+                            prot = attr.getObjValue()
+                            if prot is not None:
+                                protocolIds.append(prot.getObjId())
 
-            protocolDict[protocol.getObjId()] = protocol
+            protocolIds.append(protocol.getObjId())
 
-        return protocolDict
+        return protocolIds
 
     def getInputStatus(self):
         """ Returns if any input pointer is not ready yet and if there is
@@ -1021,6 +1029,10 @@ class Protocol(Step):
         stepsSet.write()
         stepsSet.close()  # Close the connection
 
+    def getPath(self, *paths):
+        """ Same as _getPath but without underscore. """
+        return self._getPath(*paths)
+
     def _getPath(self, *paths):
         """ Return a path inside the workingDir. """
         return os.path.join(self.workingDir.get(), *paths)
@@ -1324,6 +1336,15 @@ class Protocol(Step):
         pass
 
     def copy(self, other, copyId=True, excludeInputs=False):
+        """
+        Copies its attributes into the passed protocol
+
+        :param other: protocol instance to copt the attributes to
+        :param copyId: True (default) copies the identifier
+        :param excludeInputs: False (default). If true input attributes are excluded
+
+        """
+
         # Input attributes list
         inputAttributes = []
 
@@ -1737,14 +1758,16 @@ class Protocol(Step):
 
     @classmethod
     def validatePackageVersion(cls, varName, errors):
-        """ Function to validate the the package version specified in
+        """
+        Function to validate the package version specified in
         configuration file ~/.config/scipion/scipion.conf is among the available
         options and it is properly installed.
-        Params:
-            package: the package object (ej: eman2 or relion). Package should contain the
-                     following methods: getVersion(), getSupportedVersions()
-            varName: the expected environment var containing the path (and version)
-            errors: list to added error if found
+
+        :param package: the package object (ej: eman2 or relion). Package should contain the
+            following methods: getVersion(), getSupportedVersions()
+        :param varName: the expected environment var containing the path (and version)
+        :param errors: list of strings to add errors if found
+
         """
         package = cls.getClassPackage()
         packageName = cls.getClassPackageName()
@@ -2256,6 +2279,12 @@ class Protocol(Step):
         """
         pass
 
+    def getSize(self):
+        """ Returns the size of the folder corresponding to this protocol"""
+        if not self._size:
+            self._size = getFileSize(self.getPath())
+
+        return self._size
 
 class LegacyProtocol(Protocol):
     """ Special subclass of Protocol to be used when a protocol class
@@ -2276,14 +2305,18 @@ class LegacyProtocol(Protocol):
 # ---------- Helper functions related to Protocols --------------------
 
 def runProtocolMain(projectPath, protDbPath, protId):
-    """ Main entry point when a protocol will be executed.
-    This function should be called when:
-    scipion runprotocol ...
-    Params:
-        projectPath: the absolute path to the project directory.
-        protDbPath: path to protocol db relative to projectPath
-        protId: id of the protocol object in db.
     """
+    Main entry point when a protocol will be executed.
+    This function should be called when::
+
+        scipion runprotocol ...
+
+    :param projectPath: the absolute path to the project directory.
+    :param protDbPath: path to protocol db relative to projectPath
+    :param protId: id of the protocol object in db.
+
+    """
+
     # Enter to the project directory and load protocol from db
     protocol = getProtocolFromDb(projectPath, protDbPath, protId, chdir=True)
 
@@ -2404,7 +2437,7 @@ def isProtocolUpToDate(protocol):
     dbTS = pwutils.getFileLastModificationDate(protocol.getDbPath())
 
     if not (protTS and dbTS):
-        print("Can't compare if protocol is up to date: "
+        logger.info("Can't compare if protocol is up to date: "
               "Protocol %s, protocol time stamp: %s, %s timeStamp: %s"
               % (protocol, protTS, protocol, dbTS))
     else:
